@@ -34,32 +34,32 @@ class QModelIndex;
 class OperatorsModel;
 
 /**
-	@author Aleix Pol
+    @author Aleix Pol
 */
 class Dictionary : public QWidget
 {
 Q_OBJECT
-	public:
-		Dictionary(QWidget *p=0);
-		virtual ~Dictionary();
-		
-		QSortFilterProxyModel* model() const { return m_sortProxy; }
-		
-	public slots:
-		void activated(const QModelIndex& prev, const QModelIndex& );
-		void setFilter(const QString&);
-		
-	private:
-		QLabel *m_name;
-		QLabel *m_descr;
-		QLabel *m_sample;
-		QLabel *m_example;
-		
-		Analitza::PlotsView2D *m_graph;
-		Analitza::PlotsModel *m_funcs;
-		OperatorsModel *m_ops;
-		Analitza::Variables* m_vars;
-		QSortFilterProxyModel *m_sortProxy;
+    public:
+        Dictionary(QWidget *p=0);
+        virtual ~Dictionary();
+        
+        QSortFilterProxyModel* model() const { return m_sortProxy; }
+        
+    public Q_SLOTS:
+        void activated(const QModelIndex& prev, const QModelIndex& );
+        void setFilter(const QString&);
+        
+    private:
+        QLabel *m_name;
+        QLabel *m_descr;
+        QLabel *m_sample;
+        QLabel *m_example;
+        
+        Analitza::PlotsView2D *m_graph;
+        Analitza::PlotsModel *m_funcs;
+        OperatorsModel *m_ops;
+        Analitza::Variables* m_vars;
+        QSortFilterProxyModel *m_sortProxy;
 };
 
 #endif
